@@ -9,6 +9,7 @@ import sys
 import os
 import numpy as np
 import cv2
+import time
 from antgo.dataflow.dataset import *
 from antgo.framework.helper.fileio.file_client import *
 
@@ -22,10 +23,24 @@ class ADE20K(Dataset):
     super(ADE20K, self).__init__(train_or_test, dir,ext_params=ext_params)
     assert(train_or_test in ['train', 'val', 'test'])
 
-    if not os.path.exists(os.path.join(self.dir, 'ADEChallengeData2016')):
-      ali = AliBackend()
-      ali.download('ali:///dataset/ade20k/ADEChallengeData2016.zip', self.dir)
-      os.system(f'cd {self.dir} && unzip ADEChallengeData2016.zip')
+    if os.environ.get('LOCAL_RANK', 0) == 0:
+      if not os.path.exists(os.path.join(self.dir, 'ADEChallengeData2016')):
+        # 数据集不存在，需要重新下载，并创建标记
+        os.makedirs(self, exist_ok=True)
+        ali = AliBackend()
+        ali.download('ali:///dataset/ade20k/ADEChallengeData2016.zip', self.dir)
+        os.system(f'cd {self.dir} && unzip ADEChallengeData2016.zip')
+        os.system('touch DATASET_IS_READY')
+      else:
+        # 数据集存在，创建标记
+        if not os.path.exists('DATASET_IS_READY'):
+          os.system('touch DATASET_IS_READY')
+    else:
+      while True:
+        # 等待直到存在指定文件
+        if os.path.exists('DATASET_IS_READY'):
+          break
+        time.sleep(5)
 
     subfolder_name = 'training' if self.train_or_test == 'train' else 'validation'
     self._image_file_list = []
