@@ -1,4 +1,3 @@
-# Copyright (c) OpenMMLab. All rights reserved.
 import torch
 from antgo.framework.helper.models.builder import DETECTORS, build_backbone, build_head, build_neck
 from .base import BaseDetector
@@ -6,6 +5,74 @@ from .core.bbox import bbox2result
 from antgo.framework.helper.runner import *
 
 
+class ImageList(object):
+    """
+    Structure that holds a list of images (of possibly
+    varying sizes) as a single tensor.
+    This works by padding the images to the same size,
+    and storing in a field the original sizes of each image
+    """
+
+    def __init__(self, tensors, image_sizes):
+        """
+        Arguments:
+            tensors (tensor)
+            image_sizes (list[tuple[int, int]])
+        """
+        self.tensors = tensors
+        self.image_sizes = image_sizes
+
+    def to(self, *args, **kwargs):
+        cast_tensor = self.tensors.to(*args, **kwargs)
+        return ImageList(cast_tensor, self.image_sizes)
+
+
+def to_image_list(tensors, metas, size_divisible=0):
+    """
+    tensors can be an ImageList, a torch.Tensor or
+    an iterable of Tensors. It can't be a numpy array.
+    When tensors is an iterable of Tensors, it pads
+    the Tensors with zeros so that they have the same
+    shape
+    """
+    if isinstance(tensors, torch.Tensor) and size_divisible > 0:
+        tensors = [tensors]
+
+    if isinstance(tensors, ImageList):
+        return tensors, metas
+    elif isinstance(tensors, torch.Tensor):
+        # single tensor shape can be inferred
+        if tensors.dim() == 3:
+            tensors = tensors[None]
+        assert tensors.dim() == 4
+        image_sizes = [tensor.shape[-2:] for tensor in tensors]
+        return ImageList(tensors, image_sizes), metas
+    elif isinstance(tensors, (tuple, list)):
+        max_size = tuple(max(s) for s in zip(*[img.shape for img in tensors]))
+
+        # TODO Ideally, just remove this and let me model handle arbitrary
+        # input sizs
+        if size_divisible > 0:
+            import math
+
+            stride = size_divisible
+            max_size = list(max_size)
+            max_size[1] = int(math.ceil(max_size[1] / stride) * stride)
+            max_size[2] = int(math.ceil(max_size[2] / stride) * stride)
+            max_size = tuple(max_size)
+
+        batch_shape = (len(tensors),) + max_size
+        batched_imgs = tensors[0].new(*batch_shape).zero_()
+        for img, pad_img, meta in zip(tensors, batched_imgs, metas):
+            pad_img[: img.shape[0], : img.shape[1], : img.shape[2]].copy_(img)
+            meta.update({'image_shape': batch_shape[-2:]})
+
+        image_sizes = [im.shape[-2:] for im in tensors]
+        return ImageList(batched_imgs, image_sizes), metas
+    else:
+        raise TypeError("Unsupported type for to_image_list: {}".format(type(tensors)))
+
+
 @DETECTORS.register_module()
 class SingleStageDetector(BaseDetector):
     """Base class for single-stage detectors.
@@ -72,6 +139,8 @@ class SingleStageDetector(BaseDetector):
         Returns:
             dict[str, Tensor]: A dictionary of loss components.
         """
+        image_list, image_meta = to_image_list(image, image_meta)
+        image = image_list.tensors
         super(SingleStageDetector, self).forward_train(image, image_meta)
         x = self.extract_feat(image)
         
@@ -100,6 +169,9 @@ class SingleStageDetector(BaseDetector):
                 The outer list corresponds to each image. The inner list
                 corresponds to each class.
         """
+        image_list, image_meta = to_image_list(image, image_meta)
+        image = image_list.tensors
+        
         feat = self.extract_feat(image)
         results_list = self.bbox_head.simple_test(
             feat, image_meta, rescale=rescale)
