@@ -1,27 +1,23 @@
 # 优化器配置
-optimizer = dict(type='SGD', lr=0.05,  weight_decay=5e-4, momentum=0.01, nesterov=True)
+optimizer = dict(type='SGD', lr=0.05,  weight_decay=5e-4, momentum=0.9, nesterov=True)
 optimizer_config = dict(grad_clip=None)
 
 # 学习率调度配置
 lr_config = dict(
     policy='CosineAnnealing',
     min_lr=1e-5,
+    warmup_by_epoch=False,
+    warmup_iters=2000,
+    warmup='linear'    
 )
 
 # 日志配置
 log_config = dict(
-    interval=50,    
+    interval=10,    
     hooks=[
         dict(type='TextLoggerHook'),
     ])
 
-# 自定义HOOKS
-custom_hooks = [
-    dict(
-        type='EMAHook'
-    )
-]
-
 # 模型配置
 model = dict(
     type='EncoderDecoder',
@@ -57,8 +53,10 @@ data=dict(
         dir='./pascal2012_dataset',
         ext_params=dict(task_type='SEGMENTATION', aug=True),
         pipeline=[
-            dict(type="Meta"),
+            dict(type='Rotation'),
             dict(type='ResizeS', target_dim=(256,256)),
+            dict(type='ColorDistort'),
+            dict(type='RandomFlipImage', swap_ids=[], swap_labels=[]),
             dict(type='ToTensor', keys=['image']),
             dict(type='Normalize', mean=(0.491400, 0.482158, 0.4465231), std=(0.247032, 0.243485, 0.2615877), keys=['image']),
             dict(type='UnSqueeze', axis=0, keys=['segments'])
@@ -79,7 +77,6 @@ data=dict(
         dir='./pascal2012_dataset',
         ext_params=dict(task_type='SEGMENTATION', aug=True),
         pipeline=[
-            dict(type="Meta"),
             dict(type='ResizeS', target_dim=(256,256)),
             dict(type='ToTensor', keys=['image']),
             dict(type='Normalize', mean=(0.491400, 0.482158, 0.4465231), std=(0.247032, 0.243485, 0.2615877), keys=['image']),
@@ -101,7 +98,6 @@ data=dict(
         dir='./pascal2012_dataset',
         ext_params=dict(task_type='SEGMENTATION', aug=True),
         pipeline=[
-            dict(type="Meta"),
             dict(type='ResizeS', target_dim=(256,256)),
             dict(type='ToTensor', keys=['image']),
             dict(type='Normalize', mean=(0.491400, 0.482158, 0.4465231), std=(0.247032, 0.243485, 0.2615877), keys=['image']),
@@ -129,4 +125,4 @@ export=dict(
     output_name_list=["heatmap"]
 )
 
-max_epochs = 60
\ No newline at end of file
+max_epochs = 600
\ No newline at end of file
