@@ -4,7 +4,7 @@ from .filter_funcs import (filter_by_tags)
 from .package import (package_to_kv, package_to_tfrecord)
 from .download_funcs import (download_from_baidu, download_from_bing, download_from_vcg)
 from .label_funcs import (label_to_studio, label_from_studio, label_start, label_from_native, label_to_merge)
-
+from .share_funcs import (share_data_func)
 __all__ = [
     'extract_from_videos', 
     'extract_from_images', 
@@ -22,5 +22,6 @@ __all__ = [
     'label_from_studio',
     'label_from_native',
     'label_start',
-    'label_to_merge'
+    'label_to_merge',
+    'share_data_func'
 ]
\ No newline at end of file
